function main_cafe
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                               ||       || 
%                                               ||*******||
% cree le        30/03/2012 par O. THUAL        ||*******||
% modifie le     21/04/2012 par O. THUAL        ||*******||
%                                              \\&&&&&&&&&//
% L'eau va-t-elle deborder du filtre a cafe ?   \\&&&&&&&// 
%                                                \\&&&&&//
%  dH/dt = - alpha H + P  avec H(0)=0               0 0
%                                                   00 
%  H : hauteur dans le filtre 
%  alpha H : debit surfacique de l'eau dans le marc de cafe
%  P : debit surfacique de l'eau injectee par le robinet
%
%  Assimilation de donnees a partir de mesures de H 
%
%  Experiences jumelles pour retrouver alpha et P :
%
%  Etat vrai :  x^t =[alpha^t; P^t]
%  Ebauche   :  x^b= [alpha^b; P^b]
%
%  Mesures : y^o =[ H^o(t1); H^o(t2);...H^o(tj) ...; H^o(tnobs)]
%              obtenues a partir de l'etat vrai
%              en ajoutant des erreurs gaussiennes
%              d'ecart-type sigR a nobs observations vraies
%
%  Operateur d'observation : 
%  y = [H(t1); H(t2);...H(tj)...; H(tnobs)] = calG(x)
%
%  Operateur d'observation linearise : 
%  dy = [dH(t1); dH(t2); ...dH(tj)...; dH(tnobs)] = G dx
% avec 
%                          [dH(t1)/dalpha         dH(t1)/dP ]
%                         [     ...                ...     ]
%   matrice nobs x 2  G = [dH(tj)/dalpha        dH(tj)/dP ]
%                        [     ...                 ...   ]
%                       [dH(tnobs)/dalpha  dH(tnobs)/dP ]
%
% Matrices de covariances des erreurs d'ebauche :  
%                          [sigBalpha^2         rho sigBalpha sigBP    ]
%     matrice 2 x 2 : B = [rho sigBalpha sigBP               sigBP^2  ]
%
% Matrices de covariances des erreurs d'observation :  
%    matrice nobs x nobs : R = sigR^2  Identite 
%  
% Methode de la fonction cout incrementale
% Jinc(dx)= 1/2 dx' B^-1 dx + 1/2 [d- G dx]' R^-1 [d- G dx]
% ou l'innovation est  d= y^o - calG(x^b)  
%
% Analyse :  x^a = [alpha^a; P^a] = x^b + K d
% ou la matrice de gain est K = B G' (G B G' + R)^-1 
%               ou encore  K = (B^-1 + G' R^-1 G)^-1 G' R^-1
%
% Visualisation des resultats : 
%    Etat vrai : bleu,  Ebauche : noir,  Analyse : rouge
%
% Fonctions appellees par le programme : 
%
% init_cafe.sci : regler les parametres de l'experience dans ce fichier
% jumelles_cafe.sci : realiser une experience jumelle
% blue.sci : methode BLUE (Best Linear Unbiased Estimation)
% calG_cafe.sci : operateur d'observation non lineaire
% G_cafe.sci : operateur d'observation linearise 
% visual_cafe.sci : visualisation des resultats
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Close figures
close all

% Clear variables
clear all

% variables globales
global jalea    % numero du tirage aletoire en cours
global cumul   % cumul d'erreur pour calcul de score
global visu   %  pour desactiver les traces des figures   


% Display title
disp("Assimilation de donees pour le probleme du filtre a cafe")

%%%%%/ Parametres de reglagge d'experiences %%%%%%%%%
jtirmax=9; % nombre de tirages aleatoires
visu=true;     % avec figures si visu=true , sans si visu=false
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%
% Lancement de l'experience 
%%%%%%%%%%%%%%/


% Lancement du generateur de tirage aleatoire
randn('seed');

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Boucle sur tirages aleatoires d'experiences jumelles 
%%%%%%%%%%%%%%%%%%%%%%%%%%%/

cumul=0;  % intialisation de cumul pour le calcul de score


for jtir=1:jtirmax
   
   % experience jumelle
   jumelles_cafe(jtir);
   
   % mettre flag=1 pour temporisation de l'affichage des figures
   flag=0; 
   if(flag==1)   
      input('Taper sur la touche ''Enter'' pour la figure suivante :' )
   end
   
end

% impression du score calcule dans jumelles.sci
score=sqrt(cumul/(2*jtirmax));
disp(sprintf('score =%5.3g',score))


